import { isExportDeclaration, isImportDeclaration, isNamedExports, isNamedImports, isNamespaceImport, } from 'typescript';
export function collectImportNames(node) {
    if (isImportDeclaration(node)) {
        if (!node.importClause) {
            return [];
        }
        const { importClause } = node;
        if (importClause.name) {
            // import def from
            return ['default'];
        }
        if (importClause.namedBindings) {
            const { namedBindings } = importClause;
            if (isNamedImports(namedBindings)) {
                // import {a as b, c} from
                return getAllNames(namedBindings.elements);
            }
            else if (isNamespaceImport(namedBindings)) {
                // import * as all from
                return ['*'];
            }
        }
    }
    else if (isExportDeclaration(node)) {
        if (!node.exportClause) {
            // export * from
            return ['*'];
        }
        const { exportClause } = node;
        if (isNamedExports(exportClause)) {
            // export {a as b, c} from
            return getAllNames(exportClause.elements);
        }
    }
    return ['__failed_parse__'];
}
function getString(v) {
    return v.getText();
}
function getAllNames(list) {
    return list.map((v) => getString(v.propertyName || v.name));
}
//# sourceMappingURL=importIds.js.map